@@ -256,6 +256,14 @@ func (r *Renderer) citation(w io.Writer, node *ast.Citation, entering bool) {
 			continue
 		}
 
+		// draft-referencing, if there is a #00 (#version) we remove it from the target as this isn't allowed.
+		if bytes.HasPrefix(c, []byte("I-D.")) {
+			hash := bytes.Index(c, []byte("#"))
+			if hash > 0 {
+				c = c[:hash]
+			}
+		}
+
 		attr := []string{fmt.Sprintf(`target="%s"`, c)}
 
 		// Attempt to parse the suffix.
@@ -268,21 +276,21 @@ func (r *Renderer) citation(w io.Writer, node *ast.Citation, entering bool) {
 				switch {
 				case bytes.HasPrefix(suf, []byte(section)):
 					num := suf[len(section):]
-					attr = append(attr, `sectionFormat="of" relative="#"`)
+					attr = append(attr, `sectionFormat="of"`)
 					attr = append(attr, `section="`+string(num)+`"`)
 
 				case bytes.HasPrefix(suf, []byte(seesection)):
 					num := suf[len(seesection):]
-					attr = append(attr, `sectionFormat="comma" relative="#"`)
+					attr = append(attr, `sectionFormat="comma"`)
 					attr = append(attr, `section="`+string(num)+`"`)
 
 				case bytes.HasPrefix(suf, []byte(seepsection)):
 					num := suf[len(seepsection):]
-					attr = append(attr, `sectionFormat="parens" relative="#"`)
+					attr = append(attr, `sectionFormat="parens"`)
 					attr = append(attr, `section="`+string(num)+`"`)
 
 				default:
-					attr = append(attr, `sectionFormat="bare" relative="#"`)
+					attr = append(attr, `sectionFormat="bare"`)
 					attr = append(attr, `section="`+string(suf)+`"`)
 				}
 			}
@@ -853,6 +861,8 @@ func (r *Renderer) RenderNode(w io.Writer, node ast.Node, entering bool) ast.Wal
 		r.title = node
 	case *mast.Authors:
 		// ignore
+	case *mast.BibliographyWrapper:
+		r.bibliographyWrapper(w, node, entering)
 	case *mast.Bibliography:
 		r.bibliography(w, node, entering)
 	case *mast.BibliographyItem:
